Documentation
¶
Index ¶
- Constants
- Variables
- func AddonCommand() *cli.Command
- func ClusterCommand() *cli.Command
- func CompareClustersCommand() *cli.Command
- func ContextCommand() *cli.Command
- func CurrentCommand() *cli.Command
- func DescribeAddonCommand() *cli.Command
- func DescribeClusterCommand() *cli.Command
- func DescribeNodegroupCommand() *cli.Command
- func ListAddonsCommand() *cli.Command
- func ListClustersCommand() *cli.Command
- func ListNodegroupsCommand() *cli.Command
- func ManPageCommand() *cli.Command
- func NodegroupCommand() *cli.Command
- func ScaleNodegroupCommand() *cli.Command
- func UpdateAddonCommand() *cli.Command
- func UpdateAllAddonsCommand() *cli.Command
- func UpdateAmiCommand() *cli.Command
- func UseCommand() *cli.Command
- func VersionCommand() *cli.Command
- func WorkloadCommand() *cli.Command
Constants ¶
const ( // ManPageFileMode defines the file permissions for the man page file ManPageFileMode = 0644 // ManPageDirMode defines the directory permissions for man page directories ManPageDirMode = 0755 )
Variables ¶
var VersionInfo = types.VersionInfo{
Version: version,
Commit: commit,
BuildDate: buildDate,
}
VersionInfo provides access to version information
Functions ¶
func AddonCommand ¶ added in v0.2.1
AddonCommand groups add-on commands
func ClusterCommand ¶ added in v0.2.1
ClusterCommand groups cluster-related subcommands using verb as subcommand
func CompareClustersCommand ¶ added in v0.2.0
CompareClustersCommand creates the compare-clusters command
func ContextCommand ¶ added in v0.5.0
ContextCommand groups context management subcommands.
func CurrentCommand ¶ added in v0.5.0
CurrentCommand: `refresh current` — prints the active context.
func DescribeAddonCommand ¶ added in v0.2.1
DescribeAddonCommand describes a single EKS add-on with configuration
func DescribeClusterCommand ¶ added in v0.2.0
DescribeClusterCommand creates the describe-cluster command
func DescribeNodegroupCommand ¶ added in v0.2.1
DescribeNodegroupCommand creates the describe-nodegroup command
func ListAddonsCommand ¶ added in v0.2.1
ListAddonsCommand lists EKS add-ons for a cluster
func ListClustersCommand ¶ added in v0.2.0
ListClustersCommand creates the list-clusters command
func ListNodegroupsCommand ¶ added in v0.2.1
ListNodegroupsCommand creates the list-nodegroups command
func ManPageCommand ¶ added in v0.1.9
func NodegroupCommand ¶ added in v0.2.1
NodegroupCommand groups nodegroup-related subcommands
func ScaleNodegroupCommand ¶ added in v0.2.1
ScaleNodegroupCommand creates the scale-nodegroup command
func UpdateAddonCommand ¶ added in v0.2.1
UpdateAddonCommand updates an EKS add-on to a target version (or latest)
func UpdateAllAddonsCommand ¶ added in v0.4.0
UpdateAllAddonsCommand updates all EKS add-ons in a cluster
func UpdateAmiCommand ¶
func UseCommand ¶ added in v0.5.0
UseCommand: `refresh use [name|-]`
kubectx-style: with no arg launches an interactive picker; with "-" swaps to the previous context.
func VersionCommand ¶
func WorkloadCommand ¶ added in v0.5.0
Types ¶
This section is empty.
Source Files
¶
- addon_group.go
- cluster_compare_formatters.go
- cluster_describe_formatters.go
- cluster_formatters.go
- cluster_group.go
- cluster_list_formatters.go
- compare_clusters.go
- context.go
- describe_addon.go
- describe_cluster.go
- describe_nodegroup.go
- list_addons.go
- list_clusters.go
- list_nodegroups.go
- manpage.go
- nodegroup_group.go
- scale_nodegroup.go
- service_factory.go
- update.go
- update_addon.go
- update_all_addons.go
- utils.go
- version.go
- workload_group.go
- workload_pdbs.go